@@ -496,8 +496,7 @@ class Auth(object):
         """Signs out a user.
         
         """
-        redirect_url = request.session.get(REDIRECT_FIELD_NAME)
-        redirect_url = redirect_url or self.settings.sign_out_redirect
+        redirect_url = self.settings.sign_out_redirect
         if callable(redirect_url):
             redirect_url = redirect_url()
         
